@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::iata;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2013-12-09 - v1.001
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.038.
+
+=item *
+
 2012-07-02 - v1.000
 
 Updated with a remote source that doubled the number of airport codes,
@@ -467,7 +473,7 @@ RRG RRI RRK RRL RRM RRN RRO RRS RRT RRV RSA RSB RSD RSE RSG RSH RSI RSJ
 RSK RSL RSN RSP RSS RST RSU RSW RSX RTA RTB RTC RTD RTE RTG RTI RTL RTM
 RTN RTP RTS RTW RTX RTY RUA RUE RUF RUG RUH RUI RUK RUM RUN RUP RUR RUS
 RUT RUU RUV RUY RVA RVC RVE RVH RVL RVN RVO RVR RVS RVY RWB RWF RWI RWL
-RWN RWP RXA RXS RYB RYK RYN RYO RYV RYY RZA RZE RZH RZN RZR RZZ SAA SAB
+RWN RWP RXA RXS RYB RYG RYK RYN RYO RYV RYY RZA RZE RZH RZN RZR RZZ SAA SAB
 SAC SAD SAE SAF SAG SAH SAI SAJ SAK SAL SAM SAN SAO SAP SAQ SAR SAS SAT
 SAU SAV SAW SAX SAY SAZ SBA SBB SBC SBD SBF SBG SBH SBI SBJ SBK SBL SBM
 SBN SBO SBP SBQ SBR SBS SBT SBU SBV SBW SBX SBY SBZ SCA SCB SCC SCD SCE
