@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2013-12-09 - v1.001
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.038.
+
+=item *
+
 2012-07-09 - v1.000
 
 Updated with a remote source that doubled the number of airport codes,
@@ -288,9 +294,9 @@ KHAF KHAI KHAO KHAR KHAT KHAX KHAY KHBB KHBC KHBG KHBH KHBO KHBR KHCA
 KHCB KHCC KHCR KHCW KHDA KHDE KHDN KHDO KHED KHEE KHEI KHES KHEY KHEZ
 KHFD KHFF KHGR KHGT KHGX KHGZ KHHF KHHH KHHI KHHR KHIB KHIE KHIF KHII
 KHIK KHIO KHKA KHKB KHKS KHKY KHLB KHLC KHLG KHLI KHLM KHLN KHLR KHLX
-KHMM KHMN KHMS KHMT KHNB KHNC KHNE KHNH KHNL KHNM KHNS KHNX KHOB KHOL
+KHMM KHMN KHMS KHMT KHNB KHNC KHND KHNE KHNH KHNL KHNM KHNS KHNX KHOB KHOL
 KHON KHOP KHOT KHOU KHPB KHPN KHPT KHPV KHPY KHQM KHRL KHRO KHRT KHSB
-KHSE KHSH KHSI KHSL KHSP KHST KHSV KHTH KHTL KHTO KHTS KHTV KHTW KHUA
+KHSE KHSI KHSL KHSP KHST KHSV KHTH KHTL KHTO KHTS KHTV KHTW KHUA
 KHUD KHUF KHUJ KHUL KHUM KHUS KHUT KHVE KHVN KHVR KHVS KHWD KHWI KHWO
 KHWV KHYA KHYG KHYL KHYR KHYS KHZL KIAB KIAD KIAG KIAH KIAN KICL KICT
 KICY KIDA KIDG KIDI KIDP KIEN KIFA KIFP KIGC KIGG KIGM KIGX KIJD KIJX
