@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::services;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -58,6 +58,12 @@ Philippe "BooK" Bruhat.
 
 =item *
 
+2014-10-13 - v1.002
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.043.
+
+=item *
+
 2014-08-18 - v1.001
 
 Changed the source link to use the services list from nmap,
@@ -820,6 +826,7 @@ dns2go
 dnsix
 dns_llq
 dnx
+docker
 docstor
 documentum
 documentum_s
